@@ -17,6 +17,8 @@
 import json
 from typing import (
     AbstractSet,
+    Dict,
+    Optional,
     Tuple,
 )
 
@@ -48,13 +50,14 @@ class JWS:
         except KeyError:
             raise JWSDecodeError('Unsupported signing algorithm.')
 
-    def encode(self, message: bytes, key: AbstractJWKBase = None, alg='HS256',
-               optional_headers: dict = None) -> str:
+    def encode(self, message: bytes, key: Optional[AbstractJWKBase] = None,
+               alg='HS256',
+               optional_headers: Optional[Dict[str, str]] = None) -> str:
         if alg not in self._supported_algs:  # pragma: no cover
             raise JWSEncodeError('unsupported algorithm: {}'.format(alg))
         alg_impl = self._retrieve_alg(alg)
 
-        header = optional_headers and optional_headers.copy() or {}
+        header = optional_headers.copy() if optional_headers else {}
         header['alg'] = alg
 
         header_b64 = b64encode(
@@ -67,7 +70,8 @@ class JWS:
 
         return signing_message + '.' + signature_b64
 
-    def _decode_segments(self, message: str) -> Tuple[dict, bytes, bytes, str]:
+    def _decode_segments(
+            self, message: str) -> Tuple[Dict[str, str], bytes, bytes, str]:
         try:
             signing_message, signature_b64 = message.rsplit('.', 1)
             header_b64, message_b64 = signing_message.split('.')
@@ -79,8 +83,9 @@ class JWS:
         signature = b64decode(signature_b64)
         return header, message_bin, signature, signing_message
 
-    def decode(self, message: str, key: AbstractJWKBase = None,
-               do_verify=True, algorithms: AbstractSet[str] = None) -> bytes:
+    def decode(self, message: str, key: Optional[AbstractJWKBase] = None,
+               do_verify=True,
+               algorithms: Optional[AbstractSet[str]] = None) -> bytes:
         if algorithms is None:
             algorithms = set(supported_signing_algorithms().keys())
 
